@@ -14,6 +14,7 @@ if (window.yourlabs == undefined) window.yourlabs = {};
 //   leave a page with unsaved form data. Setting this will enable an
 //   onbeforeunload handler that doesn't block expire().
 // - events: a list of event types to watch for activity updates.
+// - returnToUrl: a url to redirect users to expired sessions to. If this is not defined we just reload the page
 yourlabs.SessionSecurity = function(options) {
     // **HTML element** that should show to warn the user that his session will
     // expire.
@@ -39,7 +40,8 @@ yourlabs.SessionSecurity = function(options) {
     if (this.confirmFormDiscard) {
         window.onbeforeunload = $.proxy(this.onbeforeunload, this);
         $(document).on('change', ':input', $.proxy(this.formChange, this));
-        $(document).on('submit', 'form', $.proxy(this.formSubmit, this));
+        $(document).on('submit', 'form', $.proxy(this.formClean, this));
+        $(document).on('reset', 'form', $.proxy(this.formClean, this));
     }
 }
 
@@ -48,7 +50,12 @@ yourlabs.SessionSecurity.prototype = {
     // seconds.
     expire: function() {
         this.expired = true;
-        window.location.reload();
+        if (this.returnToUrl !== undefined) {
+            window.location.href = this.returnToUrl;
+        }
+        else {
+            window.location.reload();
+        }
     },
     
     // Called when there has been no activity for more than warnAfter
@@ -65,7 +72,12 @@ yourlabs.SessionSecurity.prototype = {
 
     // Called by click, scroll, mousemove, keyup.
     activity: function() {
-        this.lastActivity = new Date();
+        var now = new Date();
+        if (now - this.lastActivity < 1000)
+            // Throttle these checks to once per second
+            return;
+
+        this.lastActivity = now;
 
         if (this.$warning.is(':visible')) {
             // Inform the server that the user came back manually, this should
@@ -133,8 +145,8 @@ yourlabs.SessionSecurity.prototype = {
         $(e.target).closest('form').attr('data-dirty', true);
     },
 
-    // When a form is submited, unset data-dirty attribute.
-    formSubmit: function(e) {
+    // When a form is submitted or resetted, unset data-dirty attribute.
+    formClean: function(e) {
         $(e.target).removeAttr('data-dirty');
     }
 }
